@@ -1,7 +1,7 @@
 package Complete::Util;
 
-our $DATE = '2014-12-27'; # DATE
-our $VERSION = '0.21'; # VERSION
+our $DATE = '2015-01-13'; # DATE
+our $VERSION = '0.22'; # VERSION
 
 use 5.010001;
 use strict;
@@ -247,6 +247,9 @@ $SPEC{complete_file} = {
         exp_im_path => {
             schema  => 'bool',
         },
+        dig_leaf => {
+            schema  => 'bool',
+        },
         filter => {
             summary => 'Only return items matching this filter',
             description => <<'_',
@@ -282,6 +285,7 @@ sub complete_file {
     my $ci          = $args{ci} // $Complete::OPT_CI;
     my $map_case    = $args{map_case} // $Complete::OPT_MAP_CASE;
     my $exp_im_path = $args{exp_im_path} // $Complete::OPT_EXP_IM_PATH;
+    my $dig_leaf    = $args{dig_leaf} // $Complete::OPT_DIG_LEAF;
     my $filter = $args{filter};
 
     # if word is starts with "~/" or "~foo/" replace it temporarily with user's
@@ -345,7 +349,12 @@ sub complete_file {
 
     Complete::Path::complete_path(
         word => $word,
-        ci => $ci, map_case => $map_case, exp_im_path => $exp_im_path,
+
+        ci => $ci,
+        map_case => $map_case,
+        exp_im_path => $exp_im_path,
+        dig_leaf => $dig_leaf,
+
         list_func => $list,
         is_dir_func => sub { -d $_[0] },
         filter_func => $filter,
@@ -452,7 +461,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.21 of Complete::Util (from Perl distribution Complete-Util), released on 2014-12-27.
+This document describes version 0.22 of Complete::Util (from Perl distribution Complete-Util), released on 2015-01-13.
 
 =head1 DESCRIPTION
 
@@ -474,9 +483,7 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
- (array)
+Return value:  (array)
 
 
 =head2 combine_answers($answers, ...) -> hash
@@ -497,13 +504,12 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<answers>* => I<array>
+=item * B<answers>* => I<array[hash|array]>
 
 =back
 
-Return value:
+Return value:  (hash)
 
- (hash)
 
 Return a combined completion answer. Words from each input answer will be
 combined, order preserved and duplicates removed. The other keys from each
@@ -520,7 +526,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<array>* => I<array>
+=item * B<array>* => I<array[str]>
 
 =item * B<ci> => I<bool>
 
@@ -528,9 +534,7 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
- (array)
+Return value:  (array)
 
 
 =head2 complete_env(%args) -> array
@@ -550,9 +554,7 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
- (array)
+Return value:  (array)
 
 
 =head2 complete_file(%args) -> array
@@ -567,9 +569,11 @@ Arguments ('*' denotes required arguments):
 
 Case-insensitive matching.
 
+=item * B<dig_leaf> => I<bool>
+
 =item * B<exp_im_path> => I<bool>
 
-=item * B<filter> => I<code|str>
+=item * B<filter> => I<str|code>
 
 Only return items matching this filter.
 
@@ -592,9 +596,7 @@ included.
 
 =back
 
-Return value:
-
- (array)
+Return value:  (array)
 
 
 =head2 complete_hash_key(%args) -> array
@@ -613,9 +615,7 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
- (array)
+Return value:  (array)
 
 
 =head2 complete_program(%args) -> array
@@ -634,9 +634,7 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
- (array)
+Return value:  (array)
 
 
 =head2 hashify_answer(%args) -> hash
@@ -661,9 +659,7 @@ Metadata (extra keys) for the hash.
 
 =back
 
-Return value:
-
- (hash)
+Return value:  (hash)
 
 =for Pod::Coverage ^(complete_array)$
 
@@ -698,7 +694,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
